<h3>
    <a href="/table_name"><span class="glyphicon glyphicon-file"></span> table_name</a>
</h3>
<form action="" method="post" enctype="multipart/form-data">

    fields

    <div class="form-group">
        <label></label>
        <button id="send" name="send" class="form-control"><span class="glyphicon glyphicon-save"></span> Save</button>
    </div>
</form>
<br>
<br>