$def with(table_name)
<h3>
    <a href="/table_name"><span class="glyphicon glyphicon-file"></span> table_name</a>
</h3>
<table id="datos_tabla" class="table table-hover" cellspacing="0" width="100%">
    <thead>
        <th>table_name</th>
        <th>Edit</th>
        <th>Delete</th>
    </thead>
    <tbody>
        $for item in table_name:
        <tr>
            <td><a href='/table_name/view/$item.primary_key'>$item.primary_key</a></td>
            <td><a href='/table_name/edit/$item.primary_key'><span class="glyphicon glyphicon-pencil"></span></a></td>
            <td><a href='/table_name/delete/$item.primary_key'><span class="glyphicon glyphicon-trash"></span></a></td>
        </tr>
    </tbody>
</table>
<br>
<br>